<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt-PT" sourcelanguage="en">
  <context>
    <name>CmdRobotAddToolShape</name>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="+215"/>
      <source>Robot</source>
      <translation>Robô</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Add tool</source>
      <translation>Adicionar Ferramenta</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Add a tool shape to the robot</source>
      <translation>Adicionar uma Ferramenta de Formas para o Robô </translation>
    </message>
  </context>
  <context>
    <name>CmdRobotConstraintAxle</name>
    <message>
      <location filename="../../Command.cpp" line="+158"/>
      <source>Robot</source>
      <translation>Robô</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Place robot...</source>
      <translation>Colocar Robô ...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Place a robot (experimental!)</source>
      <translation>Colocar Robô (experimental!)</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotCreateTrajectory</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="+61"/>
      <source>Robot</source>
      <translation>Robô</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create trajectory</source>
      <translation>Criar Trajetória</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create a new empty trajectory </source>
      <translation>Criar Uma Nova Trajetória vazia</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotEdge2Trac</name>
    <message>
      <location line="+257"/>
      <source>Robot</source>
      <translation>Robô</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Edge to Trajectory...</source>
      <translation>Edge to Trajectory...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Generate a Trajectory from a set of edges</source>
      <translation>Generate a Trajectory from a set of edges</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotExportKukaCompact</name>
    <message>
      <location filename="../../CommandExport.cpp" line="+50"/>
      <source>Robot</source>
      <translation>Robô</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Kuka compact subroutine...</source>
      <translation>Kuka compact subroutine...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Export the trajectory as a compact KRL subroutine.</source>
      <translation>Export the trajectory as a compact KRL subroutine.</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotExportKukaFull</name>
    <message>
      <location line="+63"/>
      <source>Robot</source>
      <translation>Robô</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Kuka full subroutine...</source>
      <translation>Kuka full subroutine...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Export the trajectory as a full KRL subroutine.</source>
      <translation>Export the trajectory as a full KRL subroutine.</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertKukaIR125</name>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="-43"/>
      <source>Robot</source>
      <translation>Robô</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Kuka IR125</source>
      <translation>Kuka IR125</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert a Kuka IR125 into the document.</source>
      <translation>Inserir Kuka IR125 no Documento.</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertKukaIR16</name>
    <message>
      <location line="-83"/>
      <source>Robot</source>
      <translation>Robô</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Kuka IR16</source>
      <translation>Kuka IR16</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert a Kuka IR16 into the document.</source>
      <translation>Inserir Kuka IR16 no Documento.</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertKukaIR210</name>
    <message>
      <location line="+39"/>
      <source>Robot</source>
      <translation>Robô</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Kuka IR210</source>
      <translation>Kuka IR210</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert a Kuka IR210 into the document.</source>
      <translation>Inserir Kuka IR210 no Documento.</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertKukaIR500</name>
    <message>
      <location line="-85"/>
      <source>Robot</source>
      <translation>Robô</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Kuka IR500</source>
      <translation>Kuka IR500</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert a Kuka IR500 into the document.</source>
      <translation>Inserir Kuka IR500 no Documento.</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertWaypoint</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="-228"/>
      <source>Robot</source>
      <translation>Robô</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert in trajectory</source>
      <translation>Inserir na Trajetória</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert robot Tool location into trajectory</source>
      <translation>Insert robot Tool location into trajectory</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertWaypointPreselect</name>
    <message>
      <location line="+55"/>
      <source>Robot</source>
      <translation>Robô</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert in trajectory</source>
      <translation>Inserir na Trajetória</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert preselection position into trajectory (W)</source>
      <translation>Insert preselection position into trajectory (W)</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotRestoreHomePos</name>
    <message>
      <location filename="../../Command.cpp" line="-56"/>
      <source>Robot</source>
      <translation>Robô</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <source>Move to home</source>
      <translation>Mover p/ Início</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotSetDefaultOrientation</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="+62"/>
      <source>Robot</source>
      <translation>Robô</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Set default orientation</source>
      <translation>Definir Orientação Predefinida</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>set the default orientation for subsequent commands for waypoint creation</source>
      <translation>set the default orientation for subsequent commands for waypoint creation</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotSetDefaultValues</name>
    <message>
      <location line="+37"/>
      <source>Robot</source>
      <translation>Robô</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Set default values</source>
      <translation>Definir Valores Predefinidos</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>set the default values for speed, acceleration and continuity for subsequent commands of waypoint creation</source>
      <translation>set the default values for speed, acceleration and continuity for subsequent commands of waypoint creation</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotSetHomePos</name>
    <message>
      <location filename="../../Command.cpp" line="-51"/>
      <source>Robot</source>
      <translation>Robô</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <source>Set the home position</source>
      <translation>Definir Posição Início</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotSimulate</name>
    <message>
      <location line="+142"/>
      <source>Robot</source>
      <translation>Robô</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Simulate a trajectory</source>
      <translation>Simular uma Trajetória</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Run a simulation on a trajectory</source>
      <translation>Executar uma Simulação numa Trajetória</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotTrajectoryCompound</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="+175"/>
      <source>Robot</source>
      <translation>Robô</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Trajectory compound...</source>
      <translation>Trajectory compound...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Group and connect some trajectories to one</source>
      <translation>Group and connect some trajectories to one</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotTrajectoryDressUp</name>
    <message>
      <location line="-49"/>
      <source>Robot</source>
      <translation>Robô</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Dress up trajectory...</source>
      <translation>Dress up trajectory...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create a dress up object which overide som aspects of a trajectory</source>
      <translation>Create a dress up object which overide som aspects of a trajectory</translation>
    </message>
  </context>
  <context>
    <name>Gui::TaskView::TaskWatcherCommands</name>
    <message>
      <location filename="../../Workbench.cpp" line="+52"/>
      <source>Trajectory tools</source>
      <translation>Trajectory tools</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Robot tools</source>
      <translation>Robot tools</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert Robot</source>
      <translation>Insert Robot</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../Command.cpp" line="-126"/>
      <location line="+49"/>
      <location line="+100"/>
      <location line="+29"/>
      <location filename="../../CommandExport.cpp" line="-52"/>
      <location line="+65"/>
      <location filename="../../CommandInsertRobot.cpp" line="+181"/>
      <location filename="../../CommandTrajectory.cpp" line="-276"/>
      <location line="+56"/>
      <location line="+17"/>
      <location line="+229"/>
      <source>Wrong selection</source>
      <translation>Seleção errada</translation>
    </message>
    <message>
      <location line="-28"/>
      <location line="+29"/>
      <location filename="../../CommandExport.cpp" line="-64"/>
      <location line="+65"/>
      <location filename="../../CommandTrajectory.cpp" line="-301"/>
      <source>Select one Robot and one Trajectory object.</source>
      <translation>Selecionar um Robô e um Objeto da Trajetória</translation>
    </message>
    <message>
      <location line="-24"/>
      <source>Trajectory not valid</source>
      <translation>Trajetória inválida</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>You need at least two way points in a trajectory to simulate.</source>
      <translation>Para simular, precisa de pelo menos 2 pontos numa trajetória.</translation>
    </message>
    <message>
      <location filename="../../CommandExport.cpp" line="-43"/>
      <location line="+65"/>
      <source>KRL file(*.src)</source>
      <translation>Ficheiro KRL (*.src)</translation>
    </message>
    <message>
      <location line="-64"/>
      <location line="+65"/>
      <source>All Files (*.*)</source>
      <translation>Todos os Ficheiros (*.*)</translation>
    </message>
    <message>
      <location line="-64"/>
      <location line="+65"/>
      <source>Export program</source>
      <translation>Exportar Programa</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="+1"/>
      <source>Select one robot and one shape or VRML object.</source>
      <translation>Select one robot and one shape or VRML object.</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="+79"/>
      <source>No preselection</source>
      <translation>Nenhuma Pré-seleção</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>You have to hover above a geometry (Preselection) with the mouse to use this command. See documentation for details.</source>
      <translation>You have to hover above a geometry (Preselection) with the mouse to use this command. See documentation for details.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="-155"/>
      <source>Select one Robot to set home postion</source>
      <translation>Select one Robot to set home postion</translation>
    </message>
    <message>
      <location line="+49"/>
      <source>Select one Robot</source>
      <translation>Select one Robot</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="-24"/>
      <location line="+17"/>
      <source>Select one Trajectory object.</source>
      <translation>Select one Trajectory object.</translation>
    </message>
    <message>
      <location line="+84"/>
      <source>set default speed</source>
      <translation>Definir Velocidade Predefinida </translation>
    </message>
    <message>
      <location line="+1"/>
      <source>speed: (e.g. 1 m/s or 3 cm/s)</source>
      <translation>Velocidade: (ex.: 1 m/s ou 3 cm/s)</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>set default continuity</source>
      <translation>Definir Continuidade Predefinida</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>continuous ?</source>
      <translation>Contínuo?</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>set default acceleration</source>
      <translation>Definir Aceleração Predefinida</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>acceleration: (e.g. 1 m/s^2 or 3 cm/s^2)</source>
      <translation>Aceleração: (ex.: 1 m/s^2 ou 3 cm/s^2)</translation>
    </message>
    <message>
      <location line="+127"/>
      <source>Select the Trajectory which you want to dress up.</source>
      <translation>Select the Trajectory which you want to dress up.</translation>
    </message>
    <message>
      <location filename="../../Workbench.cpp" line="+26"/>
      <source>No robot files installed</source>
      <translation>No robot files installed</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please visit %1 and copy the files to %2</source>
      <translation>Please visit %1 and copy the files to %2</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::DlgTrajectorySimulate</name>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="+20"/>
      <source>Simulation</source>
      <translation>Simulação</translation>
    </message>
    <message>
      <location line="+38"/>
      <source>|&lt;</source>
      <translation>|&lt;</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>&lt;</source>
      <translation>&lt;</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>||</source>
      <translation>||</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>|&gt;</source>
      <translation>|&gt;</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>&gt;</source>
      <translation>&gt;</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>&gt;|</source>
      <translation>&gt;|</translation>
    </message>
    <message>
      <location line="+24"/>
      <source>%</source>
      <translation>%</translation>
    </message>
    <message>
      <location line="+35"/>
      <source>Type</source>
      <translation>Tipo</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Name</source>
      <translation>Nome</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>C</source>
      <translation>C</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>V</source>
      <translation>V</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>A</source>
      <translation>A</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskEdge2TracParameter</name>
    <message>
      <location filename="../../TaskEdge2TracParameter.cpp" line="+47"/>
      <source>TaskEdge2TracParameter</source>
      <translation>TaskEdge2TracParameter</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskRobot6Axis</name>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="+14"/>
      <source>Form</source>
      <translation>De</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>A1</source>
      <translation>A1</translation>
    </message>
    <message>
      <location line="+47"/>
      <source>A2</source>
      <translation>A2</translation>
    </message>
    <message>
      <location line="+47"/>
      <source>A3</source>
      <translation>A3</translation>
    </message>
    <message>
      <location line="+47"/>
      <source>A4</source>
      <translation>A4</translation>
    </message>
    <message>
      <location line="+47"/>
      <source>A5</source>
      <translation>A5</translation>
    </message>
    <message>
      <location line="+47"/>
      <source>A6</source>
      <translation>A6</translation>
    </message>
    <message>
      <location line="+57"/>
      <source>TCP: (200.23,300.23,400.23,234,343,343)</source>
      <translation>TCP: (200.23,300.23,400.23,234,343,343)</translation>
    </message>
    <message>
      <location line="+17"/>
      <source>Tool: (0,0,400,0,0,0)</source>
      <translation>Tool: (0,0,400,0,0,0)</translation>
    </message>
    <message>
      <location line="+16"/>
      <source>...</source>
      <translation>...</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.cpp" line="+52"/>
      <source>TaskRobot6Axis</source>
      <translation>TaskRobot6Axis</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskRobotControl</name>
    <message>
      <location filename="../../TaskRobotControl.cpp" line="+46"/>
      <source>TaskRobotControl</source>
      <translation>TaskRobotControl</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskRobotMessages</name>
    <message>
      <location filename="../../TaskRobotMessages.cpp" line="+46"/>
      <source>TaskRobotMessages</source>
      <translation>TaskRobotMessages</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskTrajectory</name>
    <message>
      <location filename="../../TaskTrajectory.ui" line="+20"/>
      <source>Form</source>
      <translation>De</translation>
    </message>
    <message>
      <location line="+38"/>
      <source>|&lt;</source>
      <translation>|&lt;</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>&lt;</source>
      <translation>&lt;</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>||</source>
      <translation>||</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>|&gt;</source>
      <translation>|&gt;</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>&gt;</source>
      <translation>&gt;</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>&gt;|</source>
      <translation>&gt;|</translation>
    </message>
    <message>
      <location line="+24"/>
      <source>%</source>
      <translation>%</translation>
    </message>
    <message>
      <location line="+17"/>
      <source>10 ms</source>
      <translation>10 ms</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>50 ms</source>
      <translation>50 ms</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>100 ms</source>
      <translation>100 ms</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>500 ms</source>
      <translation>500 ms</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>1 s</source>
      <translation>1 s</translation>
    </message>
    <message>
      <location line="+18"/>
      <source>Pos: (200.23, 300.23, 400.23, 234, 343 ,343)</source>
      <translation>Pos: (200.23, 300.23, 400.23, 234, 343 ,343)</translation>
    </message>
    <message>
      <location line="+26"/>
      <source>Type</source>
      <translation>Tipo</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Name</source>
      <translation>Nome</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>C</source>
      <translation>C</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>V</source>
      <translation>V</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>A</source>
      <translation>A</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.cpp" line="+44"/>
      <source>Trajectory</source>
      <translation>Trajetória</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskTrajectoryDressUpParameter</name>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.cpp" line="+48"/>
      <source>Dress Up Parameter</source>
      <translation>Dress Up Parameter</translation>
    </message>
  </context>
  <context>
    <name>TaskEdge2TracParameter</name>
    <message>
      <location filename="../../TaskEdge2TracParameter.ui" line="+14"/>
      <source>Form</source>
      <translation>De</translation>
    </message>
    <message>
      <location line="+15"/>
      <source>Hide / Show</source>
      <translation>Ocultar / Mostrar</translation>
    </message>
    <message>
      <location line="+18"/>
      <source>Edges: 0</source>
      <translation>Edges: 0</translation>
    </message>
    <message>
      <location line="+14"/>
      <source>Cluster: 0</source>
      <translation>Cluster: 0</translation>
    </message>
    <message>
      <location line="+11"/>
      <source>Sizing Value:</source>
      <translation>Sizing Value:</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>Use orientation of edge</source>
      <translation>Use orientation of edge</translation>
    </message>
    <message>
      <source>TaskEdge2TracParameter</source>
      <translation type="obsolete">TaskEdge2TracParameter</translation>
    </message>
  </context>
  <context>
    <name>TaskRobot6Axis</name>
    <message>
      <source>TaskRobot6Axis</source>
      <translation type="obsolete">TaskRobot6Axis</translation>
    </message>
  </context>
  <context>
    <name>TaskRobotControl</name>
    <message>
      <location filename="../../TaskRobotControl.ui" line="+14"/>
      <source>Form</source>
      <translation>De</translation>
    </message>
    <message>
      <location line="+23"/>
      <source>X+</source>
      <translation>X+</translation>
    </message>
    <message>
      <location line="+19"/>
      <source>Y+</source>
      <translation>Y+</translation>
    </message>
    <message>
      <location line="+19"/>
      <source>Z+</source>
      <translation>Z+</translation>
    </message>
    <message>
      <location line="+19"/>
      <source>A+</source>
      <translation>A+</translation>
    </message>
    <message>
      <location line="+19"/>
      <source>B+</source>
      <translation>B+</translation>
    </message>
    <message>
      <location line="+19"/>
      <source>C+</source>
      <translation>C+</translation>
    </message>
    <message>
      <location line="+19"/>
      <source>X-</source>
      <translation>X-</translation>
    </message>
    <message>
      <location line="+19"/>
      <source>Y-</source>
      <translation>Y-</translation>
    </message>
    <message>
      <location line="+19"/>
      <source>Z-</source>
      <translation>Z-</translation>
    </message>
    <message>
      <location line="+19"/>
      <source>A-</source>
      <translation>A-</translation>
    </message>
    <message>
      <location line="+19"/>
      <source>B-</source>
      <translation>B-</translation>
    </message>
    <message>
      <location line="+19"/>
      <source>C-</source>
      <translation>C-</translation>
    </message>
    <message>
      <location line="+12"/>
      <source>Tool 0</source>
      <translation>Ferramenta 0</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Tool</source>
      <translation>Ferramenta</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Base 0</source>
      <translation>Base 0</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Base</source>
      <translation>Base</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>World</source>
      <translation>Mundo</translation>
    </message>
    <message utf8="true">
      <location line="+9"/>
      <source>50mm / 5°</source>
      <translation>50mm / 5°</translation>
    </message>
    <message utf8="true">
      <location line="+5"/>
      <source>20mm / 2°</source>
      <translation>20mm / 2°</translation>
    </message>
    <message utf8="true">
      <location line="+5"/>
      <source>10mm / 1°</source>
      <translation>10mm / 1°</translation>
    </message>
    <message utf8="true">
      <location line="+5"/>
      <source>5mm / 0.5°</source>
      <translation>5mm / 0.5°</translation>
    </message>
    <message utf8="true">
      <location line="+5"/>
      <source>1mm / 0.1°</source>
      <translation>1mm / 0.1°</translation>
    </message>
    <message>
      <source>TaskRobotControl</source>
      <translation type="obsolete">TaskRobotControl</translation>
    </message>
  </context>
  <context>
    <name>TaskRobotMessages</name>
    <message>
      <location filename="../../TaskRobotMessages.ui" line="+14"/>
      <source>Form</source>
      <translation>De</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>clear</source>
      <translation>Limpar</translation>
    </message>
    <message>
      <source>TaskRobotMessages</source>
      <translation type="obsolete">TaskRobotMessages</translation>
    </message>
  </context>
  <context>
    <name>TaskTrajectory</name>
    <message>
      <source>Trajectory</source>
      <translation type="obsolete">Trajetória</translation>
    </message>
  </context>
  <context>
    <name>TaskTrajectoryDressUpParameter</name>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="+14"/>
      <source>Form</source>
      <translation>De</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Speed &amp; Acceleration:</source>
      <translation>Speed &amp; Acceleration:</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Speed:</source>
      <translation>Velocidade:</translation>
    </message>
    <message>
      <location line="+26"/>
      <location line="+37"/>
      <source>Use</source>
      <translation>Use</translation>
    </message>
    <message>
      <location line="-26"/>
      <source>Accel:</source>
      <translation>Acel.:</translation>
    </message>
    <message>
      <location line="+36"/>
      <source>Don't change Cont</source>
      <translation>Don't change Cont</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Continues</source>
      <translation>Continues</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Discontinues</source>
      <translation>Discontinues</translation>
    </message>
    <message>
      <location line="+15"/>
      <source>Position and Orientation:</source>
      <translation>Position and Orientation:</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>(0,0,0),(0,0,0)</source>
      <translation>(0,0,0),(0,0,0)</translation>
    </message>
    <message>
      <location line="+13"/>
      <source>...</source>
      <translation>...</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Don't change Position &amp; Orientation</source>
      <translation>Don't change Position &amp; Orientation</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Use Orientation</source>
      <translation>Use Orientation</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Add Position</source>
      <translation>Add Position</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Add Orientation</source>
      <translation>Add Orientation</translation>
    </message>
    <message>
      <source>Dress Up Parameter</source>
      <translation type="obsolete">Dress Up Parameter</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="-33"/>
      <source>Robot</source>
      <translation>Robô</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert Robots</source>
      <translation>Inserir robôs</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>&amp;Robot</source>
      <translation>&amp;Robôs</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Export trajectory</source>
      <translation>Exportar Trajetória</translation>
    </message>
  </context>
</TS>
